# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to
[Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Added

### Fixed

### Changed

### Deprecated

### Removed

## [v0.3.0](https://github.com/richardkoehler/pte-stats/releases/tag/v0.3.0) - 2024-02-15

## [v0.3.0rc1](https://github.com/richardkoehler/pte-stats/releases/tag/v0.3.0rc1) - 2024-02-15

- Minor additions

## [0.2.0](https://github.com/richardkoehler/pte-stats/releases/tag/v0.2.0) - 2023-01-12

### Added

- Minor additions

## [0.1.0](https://github.com/richardkoehler/pte-stats/releases/tag/v0.1.0) - 2022-02-01

### Added

- Initial release

[Unreleased]: https://github.com/richardkoehler/pte-stats
